@@ -118,12 +118,20 @@ class CenterOfMass(CenteringMethod):
 
         if self.config["plots_flag"]:
             fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
-            ax1.imshow(
-                self.visual_data * self.mask_for_center_of_mass,
-                norm=LogNorm(),
-                cmap="YlGn",
-                origin="lower",
-            )
+            if self.plots_info["value_auto"]:
+                ax1.imshow(
+                    self.visual_data * self.mask_for_center_of_mass,
+                    norm=LogNorm(),
+                    cmap=self.plots_info["color_map"],
+                    origin="lower",
+                )
+            else: 
+                ax1.imshow(
+                    self.visual_data * self.mask_for_center_of_mass,
+                    norm=LogNorm(self.plots_info["value_min"], self.plots_info["value_max"]),
+                    cmap=self.plots_info["color_map"],
+                    origin="lower",
+                )
             ax1.scatter(
                 self.initial_detector_center[0],
                 self.initial_detector_center[1],
@@ -143,6 +151,10 @@ class CenterOfMass(CenteringMethod):
             )
             path.mkdir(parents=True, exist_ok=True)
             ax1.legend()
+            if not self.plots_info["axis_lim_auto"]:
+                ax1.set_xlim(self.plots_info["xlim_min"], self.plots_info["xlim_max"])
+                ax1.set_ylim(self.plots_info["ylim_min"], self.plots_info["ylim_max"])
+
             plt.savefig(
                 f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_of_mass/{self.plots_info["file_name"]}.png'
             )
@@ -257,12 +269,20 @@ class CircleDetection(CenteringMethod):
         center = [xc, yc]
         if self.config["plots_flag"]:
             fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
-            ax1.imshow(
-                self.visual_data * self.mask_for_circle_detection,
-                norm=LogNorm(),
-                origin="lower",
-                cmap="YlGn",
-            )
+            if self.plots_info["value_auto"]:
+                ax1.imshow(
+                    self.visual_data * self.mask_for_circle_detection,
+                    norm=LogNorm(),
+                    origin="lower",
+                    cmap=self.plots_info["color_map"],
+                )
+            else:
+                ax1.imshow(
+                    self.visual_data * self.mask_for_circle_detection,
+                    norm=LogNorm(self.plots_info["value_min"], self.plots_info["value_max"]),
+                    origin="lower",
+                    cmap=self.plots_info["color_map"],
+                )
             ax1.scatter(
                 self.initial_detector_center[0],
                 self.initial_detector_center[1],
@@ -282,6 +302,9 @@ class CircleDetection(CenteringMethod):
             )
             path.mkdir(parents=True, exist_ok=True)
             ax1.legend()
+            if not self.plots_info["axis_lim_auto"]:
+                ax1.set_xlim(self.plots_info["xlim_min"], self.plots_info["xlim_max"])
+                ax1.set_ylim(self.plots_info["ylim_min"], self.plots_info["ylim_max"])
             plt.savefig(
                 f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_circle_detection/{self.plots_info["file_name"]}.png'
             )
@@ -375,8 +398,8 @@ class MinimizePeakFWHM(CenteringMethod):
             )
 
             plt.title("Azimuthal integration")
-            plt.xlim(0, 500)
-            plt.ylim(0, 5)
+            #plt.xlim(0, 500)
+            #plt.ylim(0, 5)
             plt.legend()
             path = pathlib.Path(
                 f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/radial_average/'
@@ -490,24 +513,20 @@ class MinimizePeakFWHM(CenteringMethod):
         self.pixel_step = 1
         xx, yy = np.meshgrid(
             np.arange(
-                self.initial_guess[0] - self.config["outlier_distance"],
-                self.initial_guess[0] + self.config["outlier_distance"] + 1,
+                self.initial_guess[0] - 20,
+                self.initial_guess[0] + 21,
                 self.pixel_step,
                 dtype=int,
             ),
             np.arange(
-                self.initial_guess[1] - self.config["outlier_distance"],
-                self.initial_guess[1] + self.config["outlier_distance"] + 1,
+                self.initial_guess[1] - 20,
+                self.initial_guess[1] + 21,
                 self.pixel_step,
                 dtype=int,
             ),
         )
         coordinates = np.column_stack((np.ravel(xx), np.ravel(yy)))
 
-        ## TEST avoid effects from secondary peaks
-        # ring_mask_array=ring_mask(masked_data,initial_guess config["peak_region"]["min"], config["peak_region"]["max"])
-        # masked_data[~ring_mask_array]=0
-
         pool = multiprocessing.Pool()
         with pool:
             self.fwhm_summary = pool.map(self._calculate_fwhm, coordinates)
@@ -534,12 +553,20 @@ class MinimizePeakFWHM(CenteringMethod):
 
         if self.config["plots_flag"]:
             fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
-            ax1.imshow(
-                self.visual_data * self.mask_for_fwhm_min,
-                norm=LogNorm(),
-                origin="lower",
-                cmap="YlGn",
-            )
+            if self.plots_info["value_auto"]:
+                ax1.imshow(
+                    self.visual_data * self.mask_for_fwhm_min,
+                    norm=LogNorm(),
+                    origin="lower",
+                    cmap=self.plots_info["color_map"],
+                )
+            else:
+                ax1.imshow(
+                    self.visual_data * self.mask_for_fwhm_min,
+                    norm=LogNorm(self.plots_info["value_min"], self.plots_info["value_max"]),
+                    origin="lower",
+                    cmap=self.plots_info["color_map"],
+                )
             ax1.scatter(
                 self.initial_detector_center[0],
                 self.initial_detector_center[1],
@@ -566,6 +593,9 @@ class MinimizePeakFWHM(CenteringMethod):
             )
             path.mkdir(parents=True, exist_ok=True)
             ax1.legend()
+            if not self.plots_info["axis_lim_auto"]:
+                ax1.set_xlim(self.plots_info["xlim_min"], self.plots_info["xlim_max"])
+                ax1.set_ylim(self.plots_info["ylim_min"], self.plots_info["ylim_max"])
             plt.savefig(
                 f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/center_fwhm_minimization/{self.plots_info["file_name"]}.png'
             )
@@ -590,78 +620,33 @@ class FriedelPairs(CenteringMethod):
 	        "folder_name": "",
 	        "root_path": ""
             }
-    def _remove_repeated_pairs(self, pairs_list: list) -> list:
-        x_vector = []
-        y_vector = []
-        unique_pairs = []
-
-        for pair in pairs_list:
-            peak_0, peak_1 = pair
-            x = peak_0[0] - peak_1[0]
-            y = peak_0[1] - peak_1[1]
-            if x not in x_vector and y not in y_vector:
-                x_vector.append(x)
-                y_vector.append(y)
-                unique_pairs.append((peak_0, peak_1))
-        return unique_pairs
-
-    def _shift_inverted_peaks_and_calculate_minimum_distance(
-        self,
-        shift: list,
-    ) -> dict:
-        peaks_list = self.peaks_list_original.copy()
-        inverted_peaks = self.peaks_list_inverted.copy()
-
-        shifted_inverted_peaks = [
-            (x + shift[0], y + shift[1]) for x, y in inverted_peaks
-        ]
-        distance = self.calculate_pair_distance(peaks_list, shifted_inverted_peaks)
-
-        return {
-            "shift_x": shift[0],
-            "xc": (shift[0] / 2) + self.initial_guess[0] + 0.5,
-            "shift_y": shift[1],
-            "yc": (shift[1] / 2) + self.initial_guess[1] + 0.5,
-            "d": distance,
-        }
-
-    def calculate_pair_distance(
-        self, peaks_list: list, shifted_peaks_list: list
-    ) -> float:
-        d = [
-            math.sqrt(
-                (peaks_list[idx][0] - i[0]) ** 2 + (peaks_list[idx][1] - i[1]) ** 2
-            )
-            for idx, i in enumerate(shifted_peaks_list)
-        ]
-        return sum(d)
 
     def _select_closest_peaks(self, peaks_list: list, inverted_peaks: list) -> list:
-        peaks = []
-        for i in inverted_peaks:
-            radius = 1
+        pairs_list = []
+        for i in peaks_list:
+            radius = 0.1
             found_peak = False
             while not found_peak and radius <= self.config["search_radius"]:
-                found_peak = self._find_a_peak_in_the_surrounding(peaks_list, i, radius)
-                radius += 1
+                found_peak = self._find_a_peak_in_the_surrounding(i, inverted_peaks, radius)
+                radius += 0.1
             if found_peak:
-                peaks.append((found_peak, i))
-        # peaks = self._remove_repeated_pairs(peaks)
-        return peaks
+                pairs_list.append((i, found_peak))
+        pairs_list = self._check_paired_reflections(pairs_list)
+        return pairs_list
 
     def _find_a_peak_in_the_surrounding(
-        self, peaks_list: list, inverted_peak: list, radius: int
+        self, peak: list, inverted_peaks_list: list, radius: float
     ) -> list:
         cut_peaks_list = []
         cut_peaks_list = [
             (
-                peak,
+                inverted_peak,
                 math.sqrt(
                     (peak[0] - inverted_peak[0]) ** 2
                     + (peak[1] - inverted_peak[1]) ** 2
                 ),
             )
-            for peak in peaks_list
+            for inverted_peak in inverted_peaks_list
             if math.sqrt(
                 (peak[0] - inverted_peak[0]) ** 2 + (peak[1] - inverted_peak[1]) ** 2
             )
@@ -674,6 +659,19 @@ class FriedelPairs(CenteringMethod):
         else:
             return cut_peaks_list[0][0]
 
+    def _check_paired_reflections(self, pairs_list:list)-> list:
+        ## check if the reversed peak is also on the list
+        filtered_pairs = []
+        
+        for original_peak, inverted_peak in pairs_list:
+            inverted_peak_inverted_twice = (-1*inverted_peak[0],-1*inverted_peak[1])
+            original_peak_inverted_twice = (-1*original_peak[0],-1*original_peak[1])
+            inverted_pair=(inverted_peak_inverted_twice,original_peak_inverted_twice)
+            if inverted_pair in pairs_list:
+                filtered_pairs.append((original_peak, inverted_peak))
+
+        return filtered_pairs
+
     def _prep_for_centering(self, data: np.ndarray, initial_guess: tuple) -> None:
 
         self.initial_guess = initial_guess
@@ -750,7 +748,6 @@ class FriedelPairs(CenteringMethod):
                 )
 
         peak_list_in_slab = pf8.peak_list_in_slab(peak_list)
-        #print(peak_list_in_slab)
         self.peak_list_x_in_frame, self.peak_list_y_in_frame = peak_list_in_slab
 
     def _run_centering(self, **kwargs) -> tuple:
@@ -764,57 +761,50 @@ class FriedelPairs(CenteringMethod):
         inverted_peaks = list(zip(inverted_peaks_x, inverted_peaks_y))
         pairs_list = self._select_closest_peaks(peaks, inverted_peaks)
 
-        ## Grid search of shifts around the detector center
-        self.pixel_step = 0.2
-        xx, yy = np.meshgrid(
-            np.arange(
-                -self.config["outlier_distance"],
-                self.config["outlier_distance"] + 0.2,
-                self.pixel_step,
-                dtype=float,
-            ),
-            np.arange(
-                -self.config["outlier_distance"],
-                self.config["outlier_distance"] + 0.2,
-                self.pixel_step,
-                dtype=float,
-            ),
-        )
-        coordinates = np.column_stack((np.ravel(xx), np.ravel(yy)))
+        ## Calculcate the beam center shift
+        
         self.peaks_list_original = [x for x, y in pairs_list]
         self.peaks_list_inverted = [y for x, y in pairs_list]
 
-        pool = multiprocessing.Pool()
-        with pool:
-            distance_summary = pool.map(
-                self._shift_inverted_peaks_and_calculate_minimum_distance, coordinates
-            )
+        if len(pairs_list)>0:
+            print(f"--------------  Friedel pairs search --------------\nNumber of Friedel Pairs in frame: {len(pairs_list)/2}")
+            print(f"Pairs list for analysis:")
+            print(pairs_list)
 
-        ## Minimize distance
-        if self.config["plots_flag"]:
-            path = pathlib.Path(
-                f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/distance_map/'
-            )
-            path.mkdir(parents=True, exist_ok=True)
+            friedel_coordinates_in_x = [x for x, y in self.peaks_list_original]
+            friedel_coordinates_in_y = [y for x, y in self.peaks_list_original]
+            
+            print(f"Friedel pairs position before center correction in pixels:")
+            print(self.peaks_list_original)
+            
+            shift_x = sum(friedel_coordinates_in_x)/len(friedel_coordinates_in_x)
+            shift_y = sum(friedel_coordinates_in_y)/len(friedel_coordinates_in_y)
+            print("Center shift in x", shift_x)
+            print("Center shift in y", shift_y)
+            center = [self.initial_guess[0]+shift_x, self.initial_guess[1]+shift_y]
 
-        center = get_distance_map_global_min(
-            distance_summary,
-            f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}',
-            f'{self.plots_info["file_name"]}',
-            self.pixel_step,
-            self.config["plots_flag"],
-        )
+            print(f"Friedel pairs position after center correction in pixels:")
+            pairs_list_after_correction=[(x[0]-shift_x, x[1]-shift_y) for x in self.peaks_list_original]
+            print(pairs_list_after_correction)
+            print(f"All reflections after center correction in pixels:")
+            peaks_list_after_correction=[(x[0]-shift_x, x[1]-shift_y) for x in peaks]
+            print(peaks_list_after_correction)
 
+        else:
+            center = [-1, -1]
 
         if self.config["plots_flag"] and self.centering_converged(center):
-            shift_x = 2 * (center[0] - self.initial_guess[0])
-            shift_y = 2 * (center[1] - self.initial_guess[1])
 
-            fig, ax = plt.subplots(1, 1, figsize=(10, 10))
-            pos = ax.imshow(
-                self.visual_data, norm=LogNorm(), cmap="YlGn", origin="lower"
-            )
-            ax.scatter(
+            fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
+            if self.plots_info["value_auto"]:
+                pos = ax1.imshow(
+                    self.visual_data, norm=LogNorm(), cmap=self.plots_info["color_map"], origin="lower"
+                )
+            else:
+                pos = ax1.imshow(
+                    self.visual_data, norm=LogNorm(self.plots_info["value_min"], self.plots_info["value_max"]), cmap=self.plots_info["color_map"], origin="lower"
+                )
+            ax1.scatter(
                 self.initial_detector_center[0],
                 self.initial_detector_center[1],
                 color="b",
@@ -822,7 +812,7 @@ class FriedelPairs(CenteringMethod):
                 s=25,
                 label=f"Initial detector center:({np.round(self.initial_detector_center[0],1)},{np.round(self.initial_detector_center[1], 1)})",
             )
-            ax.scatter(
+            ax1.scatter(
                 self.initial_guess[0],
                 self.initial_guess[1],
                 color="lime",
@@ -831,7 +821,7 @@ class FriedelPairs(CenteringMethod):
                 label=f"Initial guess:({np.round(self.initial_guess[0],1)},{np.round(self.initial_guess[1], 1)})",
             )
 
-            ax.scatter(
+            ax1.scatter(
                 center[0],
                 center[1],
                 color="r",
@@ -839,11 +829,14 @@ class FriedelPairs(CenteringMethod):
                 s=25,
                 label=f"Refined detector center:({np.round(center[0],1)}, {np.round(center[1],1)})",
             )
-            ax.set_xlim(200, 900)
-            ax.set_ylim(200, 900)
+            
             plt.title("Center refinement: autocorrelation of Friedel pairs")
             fig.colorbar(pos, shrink=0.6)
-            ax.legend()
+            ax1.legend()
+            if not self.plots_info["axis_lim_auto"]:
+                ax1.set_xlim(self.plots_info["xlim_min"], self.plots_info["xlim_max"])
+                ax1.set_ylim(self.plots_info["ylim_min"], self.plots_info["ylim_max"])
+
             path = pathlib.Path(
                 f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/centered_friedel/'
             )
@@ -861,24 +854,30 @@ class FriedelPairs(CenteringMethod):
             ]
 
             inverted_non_shifted_peaks_x = [
-                np.round(k + self.initial_guess[0]) for k in inverted_peaks_x
+                np.round(k[0] + self.initial_guess[0]) for k in self.peaks_list_inverted
             ]
             inverted_non_shifted_peaks_y = [
-                np.round(k + self.initial_guess[1]) for k in inverted_peaks_y
+                np.round(k[1] + self.initial_guess[1]) for k in self.peaks_list_inverted
             ]
             inverted_shifted_peaks_x = [
-                np.round(k + self.initial_guess[0] + shift_x) for k in inverted_peaks_x
+                np.round(k[0] + self.initial_guess[0] + shift_x) for k in self.peaks_list_inverted
             ]
             inverted_shifted_peaks_y = [
-                np.round(k + self.initial_guess[1] + shift_y) for k in inverted_peaks_y
+                np.round(k[1] + self.initial_guess[1] + shift_y) for k in self.peaks_list_inverted
             ]
 
             ## Check pairs alignement
-            fig, ax = plt.subplots(1, 1, figsize=(10, 10))
-            pos = ax.imshow(
-                self.visual_data, norm=LogNorm(), cmap="YlGn", origin="lower"
-            )
-            ax.scatter(
+            fig, ax1 = plt.subplots(1, 1, figsize=(10, 10))
+            if self.plots_info["value_auto"]:
+                pos = ax1.imshow(
+                    self.visual_data, norm=LogNorm(), cmap=self.plots_info["color_map"], origin="lower"
+                )
+            else:
+                pos = ax1.imshow(
+                    self.visual_data, norm=LogNorm(self.plots_info["value_min"], self.plots_info["value_max"]), cmap=self.plots_info["color_map"], origin="lower"
+                )
+                
+            ax1.scatter(
                 original_peaks_x,
                 original_peaks_y,
                 facecolor="none",
@@ -889,7 +888,7 @@ class FriedelPairs(CenteringMethod):
                 label="original peaks",
             )
             
-            ax.scatter(
+            ax1.scatter(
                 inverted_non_shifted_peaks_x,
                 inverted_non_shifted_peaks_y,
                 s=80,
@@ -900,7 +899,7 @@ class FriedelPairs(CenteringMethod):
                 label="inverted peaks",
                 alpha=0.8,
             )
-            ax.scatter(
+            ax1.scatter(
                 inverted_shifted_peaks_x,
                 inverted_shifted_peaks_y,
                 facecolor="none",
@@ -912,11 +911,13 @@ class FriedelPairs(CenteringMethod):
                 label="shift of inverted peaks",
             )
             
-            ax.set_xlim(200, 900)
-            ax.set_ylim(200, 900)
+            if not self.plots_info["axis_lim_auto"]:
+                ax1.set_xlim(self.plots_info["xlim_min"], self.plots_info["xlim_max"])
+                ax1.set_ylim(self.plots_info["ylim_min"], self.plots_info["ylim_max"])
+            
             plt.title("Bragg peaks alignement")
             fig.colorbar(pos, shrink=0.6)
-            ax.legend()
+            ax1.legend()
             path = pathlib.Path(
                 f'{self.plots_info["root_path"]}/center_refinement/plots/{self.plots_info["folder_name"]}/peaks/'
             )
