@@ -12,14 +12,14 @@ from om.lib.geometry import (
 
 @dataclass
 class PF8Info:
-    max_num_peaks: np.int32
-    adc_threshold: np.int32
-    minimum_snr: np.float32
-    min_pixel_count: np.int16
-    max_pixel_count: np.int16
-    local_bg_radius: np.int16
-    min_res: np.int16
-    max_res: np.int16
+    max_num_peaks: np.int32 = 200
+    adc_threshold: np.int32 = 0
+    minimum_snr: np.float32 = 5
+    min_pixel_count: np.int16 = 2
+    max_pixel_count: np.int16 = 2000
+    local_bg_radius: np.int16 = 3
+    min_res: np.int16 = 0 
+    max_res: np.int16 = 1200
     pf8_detector_info: TypeDetectorLayoutInformation = None
     bad_pixel_map_filename: str = None
     bad_pixel_map_hdf5_path: str = None
@@ -54,15 +54,32 @@ class PF8Info:
         else:
             if not self.geometry_txt:
                 raise ValueError("Please, specify the detector geometry in CrystFEL format.")
+        
+        # Passing bad pixel maps to PF8. 
+        # Warning! It will look for campus in the geom file either 'mask0_file' or 'mask_file'. 
+        # It doesn't look for multiple masks. 
+        # It assumes bad pixels as zeros and good pixels as ones.
+        try:
+            self.bad_pixel_map_filename = [
+                x.split(" = ")[-1][:-1]
+                for x in self.geometry_txt
+                if x.split(" = ")[0] == "mask0_file"
+            ][0]
+        except IndexError:
+            self.bad_pixel_map_filename = [
+               x.split(" = ")[-1][:-1]
+                for x in self.geometry_txt
+                if x.split(" = ")[0] == "mask_file"
+            ][0]
 
-        self.bad_pixel_map_filename = [
-            x.split(" = ")[-1][:-1]
-            for x in self.geometry_txt
-            if x.split(" = ")[0] == "mask_file"
-        ][0]
-        self.bad_pixel_map_hdf5_path = [
-            x.split(" = ")[-1][:-1] for x in self.geometry_txt if x.split(" = ")[0] == "mask"
-        ][0]
+        try:
+            self.bad_pixel_map_hdf5_path = [
+                x.split(" = ")[-1][:-1] for x in self.geometry_txt if x.split(" = ")[0] == "mask0_data"
+            ][0]
+        except IndexError:
+            self.bad_pixel_map_hdf5_path = [
+                x.split(" = ")[-1][:-1] for x in self.geometry_txt if x.split(" = ")[0] == "mask"
+            ][0]
 
         geom = GeometryInformation(
             geometry_description=self.geometry_txt, geometry_format="crystfel"
